#!/usr/bin/perl
use strict;
use warnings;

#########################################################
###  USER CONFIGURATION      ############################
use constant ############################################
{
    LOGIN     => 'adsenselogin',        # your AdSense login name
    PASSWORD  => 'adsensepassword',     # your AdSense password
    REPORT_TO => 'account@domain.com'   # email address where you want reports sent
};
#########################################################

BEGIN {
    unless( $^O =~ /win/i )
    {
        my $homedir = ( getpwuid($>) )[7];
        my @user_include;
        foreach my $path (@INC) {
            if ( -d $homedir . '/perl' . $path ) {
                push @user_include, $homedir . '/perl' . $path;
            }
        }
        unshift @INC, @user_include;
    }
}

#########################################################
#    Author: Irakliy Sunguryan, www.sochi-travel.info   #
#########################################################
use File::Spec;
use MIME::Lite;
use WWW::Mechanize;

use constant {
    SAVE_LOGS => 1,                        # 1 = do, 0 = don't
    LOG_FILE_NAME => 'AdSenseFetch.log',   # only file name, path to it calculated below
    LOGIN_URI => 'https://www.google.com/accounts/ServiceLogin?service=adsense',
    CONTINUE_URI => 'https://www.google.com/accounts/ServiceLogin?service=adsense&rm=hide&alwf=true&passive=true&continue=https%3A%2F%2Fwww.google.com%2Fadsense%2Flogin-box-gaiaauth&followup=https%3A%2F%2Fwww.google.com%2Fadsense%2Flogin-box-gaiaauth'
};

# --- Find absolute path to the script itself. Used for creating log file.
my $full_name = File::Spec->rel2abs($0);
my( $vol, $dir ) = ( File::Spec->splitpath( $full_name ) )[0,1];
my $LOG_FILE =  File::Spec->catfile( File::Spec->canonpath( $vol.$dir ), LOG_FILE_NAME );



# --- Attempt to login...

my $m = WWW::Mechanize->new( autocheck => 0 );

# 1. Get login page without JavScript

$m->get( LOGIN_URI );
   
Quit( "Could not get login page [". $m->response->status_line ."]; quiting...." )
    unless $m->success;

# 2. Submit AdSense login credentials

my $fields = {
    'Email' => LOGIN,
    'Passwd' => PASSWORD
};

$m->submit_form( form_id => "gaia_loginform", fields => $fields );

Quit( "Could not submit log in form [". $m->response->status_line ."]; quiting...." )
    unless $m->success;

my $form_response = $m->content;

Quit( "Could not log in: check AdSense login credentials; quiting...." )
    unless( $form_response =~ /location\.replace/ || $form_response =~ /Sign out/ );

# 3. Follow automatic sign-in link

$m->get( CONTINUE_URI );

Quit( "Could not auto sign-in [". $m->response->status_line ."]; quiting...." )
    unless $m->success;




# --- Get the needed info

my $content = $m->content;
   $content =~ m/<h1 class="balance">.*(\$\d+.\d+).*\/h1>/s;
my $earnings = $1;


# --- Make me happy

if( $^O =~ /win/i ) {
    print $earnings; }
else {
    Email( $earnings );
}

Log( "Email sent out!" ) if SAVE_LOGS;

exit;




sub Email {
    my( $earned ) = @_;
    my $message = MIME::Lite->new(
        To => REPORT_TO,
        Subject => $earned . ' - AdSense Daily Report',
        Data => $earned
    );
    $message->send();
}

# Writes a string to the log file with date-time stamp.
sub Log {
	my( $sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst ) = localtime;
	my $dateTime = sprintf("%04d",$year+1900)."-".sprintf("%02d",$mon+1).":".sprintf("%02d",$mday)." ".
                   sprintf("%02d",$hour).":".sprintf("%02d",$min).":".sprintf("%02d",$sec);
    my $ret = 1;
    if( open my $LOG_FH, ">>", $LOG_FILE ) {
        print $LOG_FH $dateTime . " ". shift( @_ ). "\n";
        close $LOG_FH;
    }
    else { $ret = 0; }
    
    return $ret;
}

sub Quit {
    my( $msg ) = @_;
    Log( $msg ) if SAVE_LOGS;
    die $msg;
}